@@ -2,21 +2,38 @@ u"""
 Unit tests for ``django-envelope`` views.
 """
 
+import os
+
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.test import TestCase
+from django.test.utils import override_settings
+from django.utils import unittest
 from django.utils.translation import ugettext_lazy as _
 
+try:
+    import honeypot
+except ImportError:
+    honeypot = None
 
+from envelope import signals
+
+
+test_templates = (
+    os.path.join(os.path.dirname(__file__), 'templates'),
+    os.path.join(os.path.dirname(__file__), '../templates'),
+)
+@override_settings(TEMPLATE_DIRS=test_templates)
 class ContactViewTestCase(TestCase):
     u"""
     Unit tests for contact form view.
     """
-    url = reverse('envelope-contact')
-    customized_url = reverse('customized_class_contact')
+    urls = 'envelope.tests.urls'
 
     def setUp(self):
+        self.url = reverse('envelope-contact')
+        self.customized_url = reverse('customized_class_contact')
         self.honeypot = getattr(settings, 'HONEYPOT_FIELD_NAME', 'email2')
         self.form_data = {
             'sender':   'zbyszek',
@@ -52,6 +69,11 @@ class ContactViewTestCase(TestCase):
         self.assertContains(response, 'value="test (John Doe)"')
         self.assertContains(response, 'value="test@example.org"')
 
+        self.client.logout()
+        response = self.client.get(self.url)
+        self.assertNotContains(response, 'value="test (John Doe)"')
+        self.assertNotContains(response, 'value="test@example.org"')
+
     def test_prefilled_form_no_full_name(self):
         u"""
         In case the user is authenticated, but doesn't have his first and last
@@ -64,6 +86,7 @@ class ContactViewTestCase(TestCase):
         response = self.client.get(self.url)
         self.assertContains(response, 'value="test"')
 
+    @unittest.skipIf(honeypot is None, u"django-honeypot is not installed")
     def test_honeypot(self):
         u"""
         If the honeypot field is not empty, keep the spammer off the page.
@@ -97,6 +120,29 @@ class ContactViewTestCase(TestCase):
         flash_success_message = _("Thank you for your message.")
         self.assertContains(response, flash_success_message)
 
+    def test_signal_before_send(self):
+        u"""
+        A ``before_send`` signal is emitted before sending the message.
+        """
+        # ugly trick to access the variable from inner scope
+        params = {}
+        def handle_before_send(sender, request, form, **kwargs):
+            params['form'] = form
+        signals.before_send.connect(handle_before_send)
+        self.client.post(self.url, self.form_data, follow=True)
+        self.assertEqual(params['form'].cleaned_data['email'], self.form_data['email'])
+
+    def test_signal_after_send(self):
+        u"""
+        An ``after_send`` signal is sent after succesfully sending the message.
+        """
+        params = {}
+        def handle_after_send(sender, message, form, **kwargs):
+            params['message'] = message
+        signals.after_send.connect(handle_after_send)
+        self.client.post(self.url, self.form_data, follow=True)
+        self.assertIn(self.form_data['subject'], params['message'].subject)
+
     def test_custom_template(self):
         u"""
         You can change the default template used to render the form.
