@@ -24,20 +24,25 @@ class ContactView(FormView):
     Contact form view (class-based).
 
     Displays the contact form upon a GET request. If the current user is
-    authenticated, ``sender`` and ``email`` fields are automatically filled
-    with proper values.
+    authenticated, ``sender`` and ``email`` fields are automatically
+    filled with proper values.
 
-    When the form is submitted and valid, a message is sent and afterwards
-    the user is redirected to a "thank you" page (by default it is the page
-    with the form).
+    When the form is submitted and valid, a message is sent and
+    afterwards the user is redirected to a "thank you" page (by default
+    it is the page with the form).
 
     ``form_class``
         Which form class to use for contact message handling.
-        The default (:class:`envelope.forms.ContactForm`) is often enough,
-        but you can subclass it if you want, or even replace with a totally
-        custom class. The only requirement is that your custom class has a
-        ``save()`` method which should send the message somewhere. Stick to
-        the default, or its subclasses.
+        The default (:class:`envelope.forms.ContactForm`) is often
+        enough, but you can subclass it if you want, or even replace
+        with a totally custom class. The only requirement is that your
+        custom class has a ``save()`` method which should send the
+        message somewhere. Stick to the default, or its subclasses.
+
+    ``form_kwargs``
+        Additional kwargs to be used in the creation of the form. Use
+        with :class:`envelope.forms.BaseContactForm` form arguments for
+        dynamic customization of the form.
 
     ``template_name``
         Full name of the template which will display
@@ -47,10 +52,9 @@ class ContactView(FormView):
         URL of the page with some kind of a "thank you
         for your feedback", displayed after the form is successfully
         submitted. If left unset, the view redirects to itself.
-
-    .. versionadded:: 0.3.0
     """
     form_class = ContactForm
+    form_kwargs = {}
     template_name = 'envelope/contact.html'
     success_url = None
 
@@ -67,10 +71,10 @@ class ContactView(FormView):
         u"""
         Automatically fills form fields for authenticated users.
         """
-        initial = super(ContactView, self).get_initial()
+        initial = super(ContactView, self).get_initial().copy()
         user = self.request.user
         if user.is_authenticated():
-            # the user might not have a full name, depends on the registration
+            # the user might not have a full name set in the model
             if user.get_full_name():
                 sender = '%s (%s)' % (user.username, user.get_full_name())
             else:
@@ -81,6 +85,11 @@ class ContactView(FormView):
             })
         return initial
 
+    def get_form_kwargs(self):
+        kwargs = super(ContactView, self).get_form_kwargs()
+        kwargs.update(self.form_kwargs)
+        return kwargs
+
     def form_valid(self, form):
         u"""
         Sends the message and redirects the user somewhere.
@@ -111,10 +120,17 @@ class ContactView(FormView):
 def filter_spam(sender, request, form, **kwargs):
     u"""
     Handle spam filtering.
+
+    This function is called when the ``before_send`` signal fires,
+    passing the current request and form object to the function.
+    With that information in hand, all available spam filters are called.
+
+    TODO: more spam filters
     """
     from envelope.spam_filters import check_honeypot
     return check_honeypot(request, form)
 
 
-signals.before_send.connect(filter_spam, sender=ContactView,
+signals.before_send.connect(filter_spam,
+                            sender=ContactView,
                             dispatch_uid='envelope.views.filter_spam')
